@@ -46,11 +46,17 @@
 # endif
 #endif
 
+#include <stdarg.h>
+
 #ifndef HAVE_STRCASECMP_DECL
 CDECL int strcasecmp(const char *s1,const char *s2);
 CDECL int strncasecmp(const char *s1,const char *s2,size_t n);
 #endif
 
+#ifndef HAVE_VSNPRINTF_DECL
+CDECL int vsnprintf(char *,size_t,const char *,va_list);
+#endif
+
 static inline int xstrcmp(const char *s1,const char *s2)
 {
    if(s1==s2)
@@ -59,7 +65,7 @@ static inline int xstrcmp(const char *s1,const char *s2)
       return 1;
    return strcmp(s1,s2);
 }
-static inline int xstrlen(const char *s)
+static inline size_t xstrlen(const char *s)
 {
    if(s==0)
       return 0;
