@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.cc,v 1.77 2000/10/12 08:23:22 lav Exp $ */
+/* $Id: FileAccess.cc,v 1.78 2000/10/23 07:21:16 lav Exp $ */
 
 #include <config.h>
 
@@ -199,7 +199,7 @@ int   FileAccess::Poll(int fd,int ev)
    if(CheckHangup(&pfd,1))
       return -1;
    if(pfd.revents)
-      time(&event_time);
+      event_time=now;
    return pfd.revents;
 }
 
