@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.cc,v 1.172 2000/10/12 07:34:11 lav Exp $ */
+/* $Id: ftpclass.cc,v 1.176 2000/10/23 07:21:16 lav Exp $ */
 
 #include <config.h>
 
@@ -1053,8 +1053,10 @@ int   Ftp::Do()
       if(!ReconnectAllowed())
 	 return m;
 
-      if(Resolve(ftps?FTPS_DEFAULT_PORT:FTP_DEFAULT_PORT,"ftp","tcp")==MOVED)
-	 m=MOVED;
+      if(ftps)
+	 m|=Resolve(FTPS_DEFAULT_PORT,"ftps","tcp");
+      else
+	 m|=Resolve(FTP_DEFAULT_PORT,"ftp","tcp");
       if(!peer)
 	 return m;
 
@@ -1830,7 +1832,6 @@ int   Ftp::Do()
 	 TimeoutS(nop_interval-(now-nop_time));
       }
 
-      int ev=(mode==STORE?POLLOUT:POLLIN);
       oldstate=state;
 
       m|=FlushSendQueue();
@@ -1839,15 +1840,6 @@ int   Ftp::Do()
       if(state!=oldstate)
          return MOVED;
 
-      if(data_sock!=-1)
-      {
-	 if(Poll(data_sock,ev)==-1)
-	 {
-	    DataClose();
-	    Disconnect();
-	    return MOVED;
-	 }
-      }
       CheckTimeout();
 
       if(state!=oldstate)
@@ -2012,6 +2004,11 @@ void Ftp::SendArrayInfoRequests()
 	 else
 	    break;	   // otherwise, wait until it is first.
       }
+      else
+      {
+	 if(flags&SYNC_MODE)
+	    break;	   // don't flood the queues.
+      }
    }
 }
 
@@ -2858,6 +2855,7 @@ read_again:
 	 return(error_code);
       }
    }
+   event_time=now;
    if(res==0)
    {
    we_have_eof:
@@ -2982,6 +2980,7 @@ int   Ftp::Write(const void *buf,int size)
 	 return(error_code);
       }
    }
+   event_time=now;
    retries=0;
    persist_retries=0;
    assert(rate_limit!=0);
