@@ -18,13 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: keyvalue.cc,v 1.6 1999/05/22 12:43:34 lav Exp $ */
+/* $Id: keyvalue.cc,v 1.7 2000/11/14 12:16:58 lav Exp $ */
 
 #include <config.h>
 #include "keyvalue.h"
 #include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
+#include <errno.h>
 #include "xalloca.h"
 
 int KeyValueDB::Read(int fd)
@@ -228,5 +229,19 @@ int KeyValueDB::Lock(int fd,int type)
    lk.l_whence=0;
    lk.l_start=0;
    lk.l_len=0;
-   return fcntl(fd,F_SETLKW,&lk);
+   int res=fcntl(fd,F_SETLK,&lk);
+   if(res==-1 && errno==EAGAIN)
+   {
+      int retries=5;
+      for(int i=0; i<retries; i++)
+      {
+	 sleep(1);
+	 write(2,".",1);
+	 res=fcntl(fd,F_SETLK,&lk);
+	 if(res==0)
+	    break;
+      }
+      write(2,"\r",1);
+   }
+   return res;
 }
